<div align="center">
  <a href="https://github.com/ISROHarsh/premsir">
    <!-- Remove this shit if necessary -->
    <img src="https://i.imgur.com/kYn4ZQu.png" alt="Logo" width="120" height="140">
  </a>
 </div> 

<h2 align="center">premsir</h3>

<p align="center">
    <b>🍀 Compilation of all grade 11 programs, in a single library.</b>
    <br><br>
    <img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/ISROHarsh/premsir?style=social">
    <img alt="GitHub top language" src="https://img.shields.io/github/languages/top/ISROHarsh/premsir">
    <img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/ISROHarsh/premsir">
</p>

## 💻 Installation
Using PyPi:
```
python -m pip install premsir
```

Using GitHub Source
```
python -m pip install git+https://github.com/ISROHarsh/premsir
```